@@ -21,16 +21,19 @@ def prepare_id(id_):
         raise ValueError(f'Incorrect ID type: {type(id_)}')
 
 
-def paged_get(url, params, session):
+def paged_get(url, params, session,lazy=False):
     """
     Combine paged URL responses
     """
+    if lazy:
+        return paged_get_lazy(url,params,session)
+
     data = []
     while True:
         out = check_network_response(session.get(url, params=params))
         d = out.get("data", [])
         page = out.get("nextPage")
-        
+
         data.extend(d)
         if page is None or len(d) == 0 or params.get("count", 1000) >= len(d):
             break
@@ -38,9 +41,23 @@ def paged_get(url, params, session):
 
     return data
 
+def paged_get_lazy(url,params,session):
+    """
+    Combine paged URL responses; returns a generator
+    """
+    while True:
+        out = check_network_response(session.get(url, params=params))
+        d = out.get("data", [])
+        page = out.get("nextPage")
+
+        yield from d
+        if page is None or len(d) == 0 or params.get("count", 1000) >= len(d):
+            return
+        params["page"] = page
+
 
 def get_games(season=None, tournament=None, day=None, team_ids=None, pitcher_ids=None, weather=None, started=None,
-              finished=None, outcomes=None, order=None, count=None):
+              finished=None, outcomes=None, order=None, count=None, lazy=False, cache_time=5):
     """
     Get Games
 
@@ -56,6 +73,8 @@ def get_games(season=None, tournament=None, day=None, team_ids=None, pitcher_ids
         outcomes: search string to filter game outcomes.
         order: sort in ascending ('asc') or descending ('desc') order.
         count: number of entries to return.
+        lazy: whether to return a list or a generator
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     params = {}
     if season is not None and tournament is not None:
@@ -68,6 +87,8 @@ def get_games(season=None, tournament=None, day=None, team_ids=None, pitcher_ids
     if day:
         params["day"] = day - 1
     if order:
+        if order.lower() not in ('asc', 'desc'):
+            raise ValueError("Order must be 'asc' or 'desc'")
         params["order"] = order
     if count:
         params["count"] = count
@@ -82,13 +103,15 @@ def get_games(season=None, tournament=None, day=None, team_ids=None, pitcher_ids
     if outcomes:
         params["outcomes"] = outcomes
     if weather:
+        if not isinstance(weather, int):
+            raise ValueError("Weather must be an integer")
         params["weather"] = weather
 
-    s = session(None)
-    return paged_get(f'{BASE_URL}/games', params=params, session=s)
+    s = session(cache_time)
+    return paged_get(f'{BASE_URL}/games', params=params, session=s,lazy=lazy)
 
 
-def get_player_updates(ids=None, before=None, after=None, order=None, count=None):
+def get_player_updates(ids=None, before=None, after=None, order=None, count=None, lazy=False, cache_time=None):
     """
     Get player at time
 
@@ -98,6 +121,8 @@ def get_player_updates(ids=None, before=None, after=None, order=None, count=None
         after: return elements after this string or datetime timestamp.
         order: sort in ascending ('asc') or descending ('desc') order.
         count: number of entries to return.
+        lazy: whether to return a list or a generator
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(before, datetime):
         before = before.strftime(TIMESTAMP_FORMAT)
@@ -110,17 +135,21 @@ def get_player_updates(ids=None, before=None, after=None, order=None, count=None
     if after:
         params["after"] = after
     if order:
+        if order.lower() not in ('asc', 'desc'):
+            raise ValueError("Order must be 'asc' or 'desc'")
         params["order"] = order
     if count:
+        if count < 1 or count >= 1000:
+            raise ValueError("Count must be between 1 and 1000")
         params["count"] = count
     if ids:
         params["player"] = prepare_id(ids)
 
-    s = session(None)
+    s = session(cache_time)
     return paged_get(f'{BASE_URL}/players/updates', params=params, session=s)
 
 
-def get_team_updates(ids=None, before=None, after=None, order=None, count=None):
+def get_team_updates(ids=None, before=None, after=None, order=None, count=None, lazy=False, cache_time=None):
     """
     Get team at time
 
@@ -130,6 +159,8 @@ def get_team_updates(ids=None, before=None, after=None, order=None, count=None):
         after: return elements after this string or datetime timestamp.
         order: sort in ascending ('asc') or descending ('desc') order.
         count: number of entries to return.
+        lazy: whether to return a list or a generator
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(before, datetime):
         before = before.strftime(TIMESTAMP_FORMAT)
@@ -142,17 +173,21 @@ def get_team_updates(ids=None, before=None, after=None, order=None, count=None):
     if after:
         params["after"] = after
     if order:
+        if order.lower() not in ('asc', 'desc'):
+            raise ValueError("Order must be 'asc' or 'desc'")
         params["order"] = order
     if count:
+        if count < 1 or count >= 250:
+            raise ValueError("Count must be between 1 and 250")
         params["count"] = count
     if ids:
         params["team"] = prepare_id(ids)
 
-    s = session(None)
-    return paged_get(f'{BASE_URL}/teams/updates', params=params, session=s)
+    s = session(cache_time)
+    return paged_get(f'{BASE_URL}/teams/updates', params=params, session=s,lazy=lazy)
 
 
-def get_tribute_updates(before=None, after=None, order=None, count=None):
+def get_tribute_updates(before=None, after=None, order=None, count=None, lazy=False, cache_time=None):
     """
     Get Hall of Flame at time
 
@@ -161,6 +196,8 @@ def get_tribute_updates(before=None, after=None, order=None, count=None):
         after: return elements after this string or datetime timestamp.
         order: sort in ascending ('asc') or descending ('desc') order.
         count: number of entries to return.
+        lazy: whether to return a list or a generator
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(before, datetime):
         before = before.strftime(TIMESTAMP_FORMAT)
@@ -173,15 +210,19 @@ def get_tribute_updates(before=None, after=None, order=None, count=None):
     if after:
         params["after"] = after
     if order:
+        if order.lower() not in ('asc', 'desc'):
+            raise ValueError("Order must be 'asc' or 'desc'")
         params["order"] = order
     if count:
+        if count < 1 or count >= 1000:
+            raise ValueError("Count must be between 1 and 1000")
         params["count"] = count
 
-    s = session(None)
-    return paged_get(f'{BASE_URL}/tributes/updates', params=params, session=s)
+    s = session(cache_time)
+    return paged_get(f'{BASE_URL}/tributes/updates', params=params, session=s,lazy=lazy)
 
 
-def time_map(season=0, tournament=-1, day=0, include_nongame=False):
+def time_map(season=0, tournament=-1, day=0, include_nongame=False, cache_time=3600):
     """
     Map a season/day to a real-life timestamp
 
@@ -190,7 +231,7 @@ def time_map(season=0, tournament=-1, day=0, include_nongame=False):
         tournament: tournament identifier.
         day: 1-indexed day. if 0 do not filter by season.
         include_nongame: if True, include timestamps for phase changes, such as pre & post elections.
-
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     Returns:
     ```
     [
@@ -207,15 +248,15 @@ def time_map(season=0, tournament=-1, day=0, include_nongame=False):
     season = season - 1
     day = day - 1
 
-    s = session(3600)
-    map_ = s.get(f'{BASE_URL}/time/map').json()
+    s = session(cache_time)
+    map_ = check_network_response(s.get(f'{BASE_URL}/time/map'))['data']
 
     # Filter out desired events
     if tournament != -1:
         # Season is not always -1 if a tournament is active, so ignore it
-        results = list(filter(lambda x: x['tournament'] == tournament and x['day'] == day, map_['data']))
+        results = list(filter(lambda x: x['tournament'] == tournament and x['day'] == day, map_))
     else:
-        results = list(filter(lambda x: x['tournament'] == -1 and x['season'] == season and x['day'] == day, map_['data']))
+        results = list(filter(lambda x: x['tournament'] == -1 and x['season'] == season and x['day'] == day, map_))
 
     # Optionally filter out phase-change events
     if not include_nongame:
@@ -230,21 +271,27 @@ def time_map(season=0, tournament=-1, day=0, include_nongame=False):
     return results
 
 
-def get_fights(id_=None, season=0):
+def get_fights(id_=None, season=0, cache_time=None):
     """
     Return a list of boss fights
 
     Args:
         id_: fight ID.
         season: 1-indexed season. if 0 do not filter by season.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     season = season - 1
 
-    s = session(3600)
-    data = s.get(f'{BASE_URL}/fights').json()["data"]
+    s = session(cache_time)
+    data = check_network_response(s.get(f'{BASE_URL}/fights'))["data"]
     if id_:
         data = list(filter(lambda x: x['id'] == id_, data))
     if season > 1:
         data = list(filter(lambda x: x['data']['season'] == season, data))
 
     return data
+
+
+def get_stadiums(*, cache_time=3600):
+    s = session(cache_time)
+    return s.get(f'{BASE_URL}/stadiums').json()['data']
